@@ -231,6 +231,9 @@ define ([
                 r += '<br>';
 
                 // display table rows
+                if (set.length === 0) {
+                    r += '<br>(empty table, nothing to display)<br><br><br>';
+                }
                 if (set.length > 0) {
                     for (row = 0; row < set.length; row += 1) {
                         r += '<span id="row' + row + '">';
@@ -254,7 +257,7 @@ define ([
                 }
 
                 // Navigation menu (drowselect only)
-                if (targetType === 'drowselect') {
+                if (targetType === 'drowselect' && set.length > 1) {
                     r += 'Navigation:&nbsp;&nbsp;';
                     r += '<span id="navBack">[\u2190] Previous </span>';
                     r += '<span id="navForward">[\u2192] Next </span>';
@@ -396,6 +399,7 @@ define ([
 
                 // READ-ONLY entries first
                 len = dfo.entriesRead ? dfo.entriesRead.length : 0;
+                console.log("Processing " + len + "read-only dform entries");
                 for (i = 0; i < len; i += 1) {
                     entry = dfo.entriesRead[i];
                     if (lib.privCheck(entry.aclProfileRead)) {
@@ -409,6 +413,7 @@ define ([
         
                 // READ-WRITE entries second
                 len = dfo.entriesWrite ? dfo.entriesWrite.length : 0;
+                console.log("Processing " + len + "read-write dform entries");
                 for (i = 0; i < len; i += 1) {
                     entry = dfo.entriesWrite[i];
                     if (lib.privCheck(entry.aclProfileWrite)) {
